Welcome to django-seo2's documentation!
=======================================

Django-seo2 is a Django based framework, allowing you to manage SEO (Search Engine Optimisation) metadata.

First steps
===========

- :ref:`Background <introduction-background>`
- :ref:`Installation <introduction-install>`
- :ref:`Tutorial <introduction-tutorial>`
- :ref:`60 second tutorial for Django experts <introduction-blitz-tutorial>`

Reference
=========

- :ref:`Reference manual <reference-definition>`
- :ref:`Guide for site administrators <reference-administrators>`


More information
================

- :ref:`django-seo2 contributors' guide <reference-developers>`

Indices and tables
==================

- :ref:`contents`
- :ref:`genindex`
- :ref:`modindex`
- :ref:`search`

